:mod:`langacore.kit.django.filters`
===================================


.. automodule:: langacore.kit.django.filters


Functions
----------

.. autofunction:: nullify

.. autofunction:: numberify

.. autofunction:: slugify

.. autofunction:: strike_empty

.. autofunction:: title

.. autofunction:: transliterate

